<?php
/**
 * Sample code for GiroCheckout integration of a giropay + giropay-ID transaction
 *
 * The provided Notify and Redirect files (GiropayWithGiropayID_Notify.php and GiropayWithGiropayID_Redirect.php)
 * may be used for testing this script, if you have a valid URL for testing.  In that case, call this script
 * from your browser:
 * 
 * http://my.real.url/GiropayTransactionWithGiropayID.php
 * 
 * It will redirect to Giropay immediately and after the payment redirect back to the redirect page.
 * You may see the notify output on the error log.
 * 
 * @filesource
 * @package Samples
 * @version $Revision: 274 $ / $Date: 2019-09-06 14:04:44 -0400 (Fri, 06 Sep 2019) $
 */
require_once '../../GiroCheckout_SDK/GiroCheckout_SDK.php';

/**
 * configuration of the merchants identifier, project and password
 * this information can be found in the GiroCockpit's project settings
 */
$merchantID = 0;        // Your merchant ID (Verkaufer-ID)
$projectID = 0;         // Your project ID (Projekt-ID)
$projectPassword = "";  // Your project password

/* init giropay transaction an parameters */
try {
	$request = new GiroCheckout_SDK_Request( GiroCheckout_SDK_TransactionType_helper::TRANS_TYPE_GIROPAY_TRANSACTION );
	$request->setSecret($projectPassword);
	$request->addParam('merchantId',$merchantID)
	        ->addParam('projectId',$projectID)
	        ->addParam('merchantTxId',1234567890)
	        ->addParam('amount',100)
	        ->addParam('currency','EUR')
	        ->addParam('purpose','giropay+giropay-ID Zahlung')
	        ->addParam('bic','TESTDETT421')
	        ->addParam('urlRedirect','https://www.my-domain.de/girocheckout/redirect.php')
	        ->addParam('urlNotify','https://www.my-domain.de/girocheckout/redirect.php')
	    //the hash field is auto generated by the SDK
	        ->submit();

  // print_r( $request );
  
	/* if transaction succeeded update your local system an redirect the customer */
	if($request->requestHasSucceeded()) {
    $request->getResponseParam('reference');
    $request->getResponseParam('redirect');
    $request->redirectCustomerToPaymentProvider();
	}	
	/* if the transaction did not succeed update your local system, get the responsecode and notify the customer */
	else {
    $request->getResponseParam('rc');
    $request->getResponseParam('msg');
    $request->getResponseMessage($request->getResponseParam('rc'),'DE');
	}
}
catch (Exception $e) { echo $e->getMessage(); }